@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.009000";
+    our $MITE_VERSION = "0.009001";
 
     BEGIN {
         require Scalar::Util;
@@ -160,8 +160,52 @@
             $self->{"roles"} = $value;
         };
 
-        # Attribute imported_functions (type: Map[MethodName,Str])
+        # Attribute role_args (type: Map[NonEmptyStr,HashRef|Undef])
         # has declaration, file lib/Mite/Role.pm, line 51
+        do {
+            my $value =
+              exists( $args->{"role_args"} )
+              ? $args->{"role_args"}
+              : $self->_build_role_args;
+            do {
+
+                package Mite::Shim;
+                ( ref($value) eq 'HASH' ) and do {
+                    my $ok = 1;
+                    for my $v ( values %{$value} ) {
+                        ( $ok = 0, last ) unless do {
+
+                            package Mite::Shim;
+                            ( ( ref($v) eq 'HASH' ) or ( !defined($v) ) );
+                        }
+                    };
+                    for my $k ( keys %{$value} ) {
+                        ( $ok = 0, last )
+                          unless (
+                            (
+                                do {
+
+                                    package Mite::Shim;
+                                    defined($k) and do {
+                                        ref( \$k ) eq 'SCALAR'
+                                          or ref( \( my $val = $k ) ) eq
+                                          'SCALAR';
+                                    }
+                                }
+                            )
+                            && ( length($k) > 0 )
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak "Type check failed in constructor: %s should be %s",
+              "role_args", "Map[NonEmptyStr,HashRef|Undef]";
+            $self->{"role_args"} = $value;
+        };
+
+        # Attribute imported_functions (type: Map[MethodName,Str])
+        # has declaration, file lib/Mite/Role.pm, line 56
         do {
             my $value =
               exists( $args->{"imported_functions"} )
@@ -208,7 +252,7 @@
         };
 
         # Attribute required_methods (type: ArrayRef[MethodName])
-        # has declaration, file lib/Mite/Role.pm, line 56
+        # has declaration, file lib/Mite/Role.pm, line 61
         do {
             my $value =
               exists( $args->{"required_methods"} )
@@ -245,7 +289,7 @@
         };
 
         # Attribute method_signatures (type: Map[MethodName,Mite::Signature])
-        # has declaration, file lib/Mite/Role.pm, line 61
+        # has declaration, file lib/Mite/Role.pm, line 66
         do {
             my $value =
               exists( $args->{"method_signatures"} )
@@ -296,7 +340,7 @@
 
         # Unrecognized parameters
         my @unknown = grep not(
-/\A(?:attributes|imported_functions|method_signatures|name|r(?:equired_methods|oles)|s(?:him_name|ource))\z/
+/\A(?:attributes|imported_functions|method_signatures|name|r(?:equired_methods|ole(?:_args|s))|s(?:him_name|ource))\z/
         ), keys %{$args};
         @unknown
           and croak(
@@ -387,7 +431,7 @@
     }
 
     # Accessors for imported_functions
-    # has declaration, file lib/Mite/Role.pm, line 51
+    # has declaration, file lib/Mite/Role.pm, line 56
     if ($__XS) {
         Class::XSAccessor->import(
             chained   => 1,
@@ -405,7 +449,7 @@
     }
 
     # Accessors for method_signatures
-    # has declaration, file lib/Mite/Role.pm, line 61
+    # has declaration, file lib/Mite/Role.pm, line 66
     if ($__XS) {
         Class::XSAccessor->import(
             chained   => 1,
@@ -437,7 +481,7 @@
     }
 
     # Accessors for required_methods
-    # has declaration, file lib/Mite/Role.pm, line 56
+    # has declaration, file lib/Mite/Role.pm, line 61
     if ($__XS) {
         Class::XSAccessor->import(
             chained   => 1,
@@ -453,19 +497,80 @@
         };
     }
 
+    # Accessors for role_args
+    # has declaration, file lib/Mite/Role.pm, line 51
+    sub role_args {
+        @_ > 1
+          ? do {
+            do {
+
+                package Mite::Shim;
+                ( ref( $_[1] ) eq 'HASH' ) and do {
+                    my $ok = 1;
+                    for my $v ( values %{ $_[1] } ) {
+                        ( $ok = 0, last ) unless do {
+
+                            package Mite::Shim;
+                            ( ( ref($v) eq 'HASH' ) or ( !defined($v) ) );
+                        }
+                    };
+                    for my $k ( keys %{ $_[1] } ) {
+                        ( $ok = 0, last )
+                          unless (
+                            (
+                                do {
+
+                                    package Mite::Shim;
+                                    defined($k) and do {
+                                        ref( \$k ) eq 'SCALAR'
+                                          or ref( \( my $val = $k ) ) eq
+                                          'SCALAR';
+                                    }
+                                }
+                            )
+                            && ( length($k) > 0 )
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak( "Type check failed in %s: value should be %s",
+                "accessor", "Map[NonEmptyStr,HashRef|Undef]" );
+            $_[0]{"role_args"} = $_[1];
+            $_[0];
+          }
+          : ( $_[0]{"role_args"} );
+    }
+
     # Accessors for roles
     # has declaration, file lib/Mite/Role.pm, line 46
-    if ($__XS) {
-        Class::XSAccessor->import(
-            chained   => 1,
-            "getters" => { "roles" => "roles" },
-        );
-    }
-    else {
-        *roles = sub {
-            @_ == 1 or croak('Reader "roles" usage: $self->roles()');
-            $_[0]{"roles"};
-        };
+    sub roles {
+        @_ > 1
+          ? do {
+            do {
+
+                package Mite::Shim;
+                ( ref( $_[1] ) eq 'ARRAY' ) and do {
+                    my $ok = 1;
+                    for my $i ( @{ $_[1] } ) {
+                        ( $ok = 0, last )
+                          unless (
+                            do {
+                                use Scalar::Util ();
+                                Scalar::Util::blessed($i)
+                                  and $i->isa(q[Mite::Role]);
+                            }
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak( "Type check failed in %s: value should be %s",
+                "accessor", "ArrayRef[Mite::Role]" );
+            $_[0]{"roles"} = $_[1];
+            $_[0];
+          }
+          : ( $_[0]{"roles"} );
     }
 
     # Accessors for shim_name
